@@ -67,6 +67,10 @@ class Base:
     def Send(self, *args):
         self.stream.send_multipart(args)
 
+    def Close(self):
+        self.stream.close()
+        self.socket.close()
+
 class Request(Base):
     def __init__(self, **kwds):
         Base.__init__(self, zmq.REQ, **kwds)
